/*---------------------------------------------------------------------------------------
|
|   [Thermometer with Logger Function 2.0]
| 	Copyright (C) [2022]  	[Clemens Verstappen DL3ETW] 
| 
|	Controller ATmega328P and OLED Display SH1106 128*64 px
| 	Temperature sensor TSic306 and encoder. 
|	
|	Fuse: 8 MHz internel RC oszillator, 
|
|	SEE Calculation for TSic 306 and TSic 506 ! DIFFERENCE both types are supported, 
|	modify code at three position below. TSic 306 is default (accuracy 0.3 kelvin)
|
|   Function: 
|	In MEASURE mode display of present temperatur from -50 to +150 C 
| 	In GRAPH mode display of 100 logged temperatures from a float array 
|   Logging starts automatically. Display is switched off and controller goes into sleep 
|	mode. Each 15 minutes the present temperatur is measured 
|	and stored in an array of 100 datapoints.
|	Controller button resumes device in to operating GRAPH mode
|	and displays previous data collected.
|	Current consuption: 6.5 uA (!) in sleep mode.
|
|	Version:
|	2.0		Spannungsversorgung LCD ber Controller PB2, 
|	
|---------------------------------------------------------------------------------------- */

#include  	"my_defines_mega328.h"
#include 	<avr/io.h>
#include 	<stdio.h>
#include 	<util/delay.h>
#include 	<avr/interrupt.h>
#include 	<string.h> 				// 
#include 	<stdlib.h>
#include 	<stdbool.h>				// boolsche algebra
#include 	<avr/sleep.h>			// for sleep modes
#include 	<avr/wdt.h>				// for watchdog
#include 	<avr/power.h>			// and power down mode
#include 	"my_uart.h"				// serial for debugging

#include 	"oled_lcd.h"
#include 	"oled_font.h"
#include 	"my_i2c.h"

//#define		DEBUG				// UART and LED on, while debugging

static volatile bool timer_flag = false,			// main intervall e.g. 200 ms or 10 ms
 					button_flag = false,			// button of encoder switch pressed
					encoder_left_flag = false,		// encoder left turn interrupt
					encoder_right_flag = false,
					A_set = true,					// level on encoder A
					B_set = true,					// level on encoder B
					watchdog_flag = false,
					power_down_mode = false;

static 	volatile	uint8_t 	marker = 20, marker_old = 20, watchdog_counter = 0, error = 0, 
								charMode = MEASURE, charMode_old = GRAPH; 	// memorise change of mode

static 	volatile 	uint16_t	voltage_pixel_old = 0, delta_px = 0, voltage_pixel = 0,
								auto_sleep_counter = 0;

					uint16_t	temperature = 0;

					float		history[101];		// array temperatur
					float		temperature_ft;		// working variable temperatur
					char 		display_str[21];	// array for strings
  					char 		temp_str[21];

void watchdogSetup(void);
uint8_t calculate_min(void);
uint8_t calculate_max(void);		
void draw_graph(void);					 
void welcome_lcd(void);								// welcome symbole quad
void draw_coordinate_system_lcd(void);				// draw 
uint8_t getTSicTemp(uint16_t *temp_value16); 		// read sensor
void display_temp_OLED(uint8_t error);						// 

// ******************************  MAIN  ***********************************

int main(void) 	
{
// 	init port pins direction all output except ENC_A, ENC_B, ENC_SW, RESET, SENSOR_SIGNAL
//					bit 7				6				5				  4				   3			    2				    1			        	0
	DDRB 	|= (1<<UNUSED_PB7) |(1<<UNUSED_PB6) |(1<<UNUSED_PB5)  |(1<<UNUSED_PB4)   |(1<<UNUSED_PB3)    |(1<<LCD_POWER)					     |(1<<LEBENSLICHT);
	DDRC	|= 								     (1<<I2C_SCL)     |(1<<I2C_SDA)      |                    (1<<SENSOR_POWER)     |(1<<UNUSED_PC1) |(1<< UNUSED_PC0);
	DDRD	|= (1<<UNUSED_PD7) |(1<<UNUSED_PD6) |(1<<TEST_PIN)    |(1<<UNUSED_PD4)   |				      (1<<TX)|        					     (1<<UNUSED_PD0);

// default to ground
	PORTB 	&= ~(1<<UNUSED_PB7)& ~(1<<UNUSED_PB6)& ~(1<<UNUSED_PB5)& ~(1<<UNUSED_PB4)& ~(1<<LCD_POWER)	  & 	 				                 ~(1<<LEBENSLICHT);
	PORTC	&= 									   ~(1<<I2C_SCL)   & ~(1<<I2C_SDA)   & ~(1<<SENSOR_SIGNAL)& ~(1<<SENSOR_POWER)&                  ~(1<<UNUSED_PC0);
	PORTD	&= ~(1<<UNUSED_PD7)& ~(1<<UNUSED_PD6)& ~(1<<TEST_PIN  )& ~(1<<UNUSED_PD4)					  						&~(1<<TX)	   & ~(1<<UNUSED_PD0);
// 
	PORTB   |=  (1 << ENC_SW);					// 	Pull up enable, switch encoder
	PORTD   |=  (1 << ENC_A) |  (1 << ENC_B);	// 	Pull up enable, encoder

// TIMER 1									// starts handler in main each 500 ms
	OCR1A	= 	TIMER_500MS	;				// timer 1, compare match
	TCCR1B	|= 	((1 << WGM12) | (1 << CS12) | (1 << CS10)); 		// clear on compare match, divide by 1024
	TIMSK1	|= 	(1 << OCIE1A);				// timer1 compare match 1 interrupt enable

//initialize encoder
   	EICRA	|=	((1<<ISC10)|(1<<ISC00)); 		// Trigger INT0 & INT1 on changing edge
  	EIMSK	|=	((1<<INT1)|(1<<INT0));   		// Enable INT0 & INT1

// init encoder switch on Port B and PIN 1, PB1
  	PCMSK0  = 	(1 << PCINT1);				// Pin change mask register, enable PCINT1 (PB1) for interrupt  
  	PCICR   = 	(1 << PCIE0);  				// PCINT0 (7:0), PB1 resp. pin 15 DIL28

// Calibrated Internal RC Oscillator
//	OSCCAL  = 82;								// 0x8c;							// in case, adjust for UART 

//initialize OLED Display
	PORTB |= (1<<LCD_POWER);				// turn power on LCD
	_delay_ms(10); 							// stable 
   	lcd_init(LCD_DISP_ON);    				// init lcd and turn on
   	lcd_set_contrast(0xff);
   	lcd_clrscr();
	lcd_charMode(DOUBLESIZE);				// font size normal or large 1 or 2

#ifndef DEBUG
	welcome_lcd();							// welcome message
#endif
   	
	watchdogSetup();						// init clock 128 kHz for watch dog
	PORTB |= (1<<LEBENSLICHT);				// turn on Lebenslicht
	sei();									// enable all interrupts

#ifdef DEBUG								// if debugging, turn UART and LED on 
uartInitTx();								// 9600 BAUD at 8 MHz
uartPuts("INIT \n");
#endif

//	load array
	for (uint8_t tw = 1; tw <= 100; tw++) 	// load initially the data for display in array with default 21.0 degree 
		history[tw] = 21.0 ;

// ################################  main loop  #####################################################
while (1) 							// endless loop
{

//################################  handler MEASURE  ################################################

		if (timer_flag && (charMode == MEASURE))	// work here if timer_flag was set (each 500 ms)
		{
			PORTB ^= (1<<LEBENSLICHT);			// toggle Lebenslicht
			if (charMode_old != charMode)		// init Measure display only once after change
			{
				charMode_old = charMode;
				lcd_clrscr();					// clear screen, takes some time
				lcd_charMode(DOUBLESIZE);		// font size small now
#ifdef DEBUG
uartPuts(">MEAS\n"); 
#endif
			}
			error = getTSicTemp(&temperature);	// read sensor and store in temperature, read error message
			if (error==0)						// no errror  --- read TSic Sensor
			{ 														// 
				temperature_ft = (((float)(temperature))/ 2047 * 200) - 50; // TSic 306,  read temp-sensor and copy into integer array
//				temperature_ft = (((float)(temperature))/ 2047 * 70) - 10;	// TSic 506, read temp-sensor and copy into		
			}		
			else	
				temperature_ft = 0.0;
			
			history[0] = temperature_ft;
			display_temp_OLED(error);			// display temperature on display each 500 ms in MEASURE mode
	
#ifdef DEBUG
uartPuts("T= ");				// UART MELDUNG
uartPuts(display_str);			//
uartPuts(" \n");				// noch ein Linefeed und cr hinterher, uartPuts(",  \n");
#endif
			error = 0;
			timer_flag = false;					// clear button flag
		}


//################################  handler GRAPH   ###########################################

		if (timer_flag && (charMode == GRAPH))	// work here if Logger selected
		{										
			PORTB ^= (1<<LEBENSLICHT);			// toggle Lebenslicht


			if (charMode_old != charMode)		// init graph only once after change
			{
				charMode_old = charMode;
				lcd_clrscr();					// clear OLED
				lcd_charMode(NORMALSIZE);		// font size small now
				draw_coordinate_system_lcd();	// display coordinate system 

#ifdef DEBUG
uartPuts(">GRAPH\n");						// for debugging
#endif
				draw_graph();					// display measurement result of 100 points
												// use curser function for individual samples			
			}
			timer_flag = false;					// clear button flag
		}

//################################  handler ENCODER    #############################################

		if (((encoder_left_flag) || (encoder_right_flag))  && (charMode == GRAPH))	// in case of encoder rotate
		{																			// diplay time an value 
			display_str[0] 	= '\0';						// delete old contents
			temp_str[0]		= '\0';
			float time_ft	= 0.0;			
		
			time_ft = (float) marker * -1 / 4;			// value for display only
														// display min and max values at 1. line
			lcd_puts_xy(0,0,"                     ");	// clear line		
			strcat(display_str, "Marker ");				// add into string
			dtostrf(time_ft, 2, 2, temp_str);			// convert float 
			strcat(display_str, temp_str);				// add into string
			strcat(display_str, "H ");					// add space unit an space
			dtostrf(history[marker], 2, 1, temp_str);	// convert float 
			strcat(display_str, temp_str);				// add float into string
			strcat(display_str, "C");					// add unit Volts
  			lcd_puts_xy(0,0, display_str);				// now display marker string in 1. line
  			lcd_display();								// copy to display

			marker_old = marker;						// save for later delete function

			encoder_left_flag = false;
			encoder_right_flag = false;
		}

//################################  handler POWER DOWN   ###########################################

	while (power_down_mode) 					// ISR (TIMER1_COMPA_vect), auto_sleep_counter sets this flag
	{
		PORTB &= ~(1<<LEBENSLICHT);				// turn Lebenslicht off
		PORTB &= ~(1<<LCD_POWER);				// LCD OFF
			
		wdt_reset();							// reset watchdog counter
	  	set_sleep_mode(SLEEP_MODE_PWR_DOWN); 	// choose power down mode, clock for watchdog keeps runing
		sleep_mode();							// here processor terminates work.
												// but resumes work after a watchdog interrupt or pin change interrupt (button) 
						
		if (button_flag)						// wake up! if encoder button was used (power down counter)
		{										// ISR(PCINT0_vect) sets button_flag 

#ifdef DEBUG
uartInitTx();
uartPuts("BUTTON\n");				
#endif
			button_flag = false;				// reset flag
			power_down_mode = false;			// terminate power down mode now, 

			PORTB |= (1<<LCD_POWER);			// turn power on LCD 3,3 V (about 7 mA)
			_delay_ms(10); 						// charge 100 nF capacitor at Vcc 3,3 V 
   			lcd_init(LCD_DISP_ON);    			// init lcd and turn on
   			lcd_set_contrast(0xff);

			charMode = GRAPH;					// resume always GRAPH mode after power down
			charMode_old = MEASURE;			
			PORTB |= (1<<LEBENSLICHT);				// turn on Lebenslicht
			timer_flag = true;					// and enter GRAPH handler immediatly
			break;								// now exit
		}
	
		if (watchdog_flag)						// wake up and handle now watchdog (each 8.3 seconds)
		{
			watchdog_flag = false;				// 

#ifdef DEBUG
uartInitTx();
uartPuts("WDG 8.3s\n");							// for debugging
#endif
			if (watchdog_counter >= UPDATE)		// set update time in DEFINE, 15 min, 1 min or 16 seconds (mulitible of 8.3 seconds
			{
				error = getTSicTemp(&temperature);
				if (error == 0)					// no errror
				{ 																
					temperature_ft= (((float)(temperature))/ 2047 * 200) - 50;	// read temp-sensor TSic 306 and copy into integer array
//					temperature_ft = (((float)(temperature))/ 2047 * 70) - 10;	// read temp-Sensor TSic 506 and copy into array 		
					history[0] = temperature_ft;
				}
				else							// else, in case of an error
				{
					temperature_ft = 0.0;					
		    	}

				for(uint8_t i = 100; i > 0 ; i--)	// shift by one element and copy [0] in to array
				{									// i = 0 present temp, i=1 recent value, i=100 old value
					history[i] = history[i-1];
				}
#ifdef DEBUG
uartInitTx();
uartPuts("WDG update\n");							// for debugging
#endif
				watchdog_counter = 0;				// clear, count up to 15 min again
			}
		}
	}  
   } // ende while
} // ende main   ##########################################  END MAIN  ##########################################

void watchdogSetup(void)					// init for watchdog timer, here used for power down and safe current
{
  	cli();
  	wdt_reset();
  	WDTCSR |= (1<<WDCE) | (1<<WDE);
  	WDTCSR  = (1<<WDIE) | (0<<WDE) | (1<<WDP3) | (1<<WDP0);  // 8.3 s / interrupt, no system reset
  	sei();
}

uint8_t calculate_min(void)					// search for minimum value in array
{
	uint8_t    c = 1,
			   location = 1;
	for (c = 1; c <= 100; c++)
    	if (history[c] < history[location])
      		location = c;
	return location;
}

uint8_t calculate_max(void)					// search for maximum value in array
{
	uint8_t    c = 1,
			   location = 1;
	for (c = 1; c <= 100; c++)
    	if (history[c] > history[location])	// here >
      		location = c;
	return location;
}


void draw_graph(void)					// read array and draw graph
{
	display_str[0] 	= '\0';				// delete old contents
	temp_str[0]		= '\0';

	float	t_max	= history[calculate_max()];		// find and store max value in array
	float	t_min	= history[calculate_min()];		// find and sotre min valuel in array
	float	y_gain;
	int		y_offset, y_pixel, y_pixel_old=0;

	y_gain =  (50 / (t_max - t_min));		// calculate gain of slope (y = mx + b)  
											// y_gain signed integer 16 bit 							
	y_offset = (int)((-1)* y_gain * t_min);

for (uint8_t time_counter = 1; time_counter <= 100; time_counter++ ) 	// draw graph
{
	y_pixel = (int) (y_gain * history[101-time_counter] + y_offset);	// read each values multiplay with gain and add offset of slope	
							
	delta_px = 	y_pixel - y_pixel_old;
																	// draw graph of signal on display 
	lcd_drawLine(OFFSET_X + time_counter, OFFSET_Y - y_pixel, OFFSET_X + time_counter ,OFFSET_Y - y_pixel + delta_px, WHITE);
	lcd_drawLine(OFFSET_X + time_counter, OFFSET_Y - y_pixel, OFFSET_X + time_counter ,OFFSET_Y - y_pixel + delta_px +1 , WHITE); // second line thick
	y_pixel_old = y_pixel;
};
										// hier min und max 
	lcd_puts_xy(0,0,"                  ");		// clear temp line	
	strcat(display_str, "Min:");				// add unit Celsius
	dtostrf(t_min, 2, 1, temp_str);		// convert float to ascii 
	strcat(display_str, temp_str);
	strcat(display_str, "C ");
	strcat(display_str, "Max:");		// add unit Celsius		
	dtostrf(t_max, 2, 1, temp_str);		// convert float to ascii 
	strcat(display_str, temp_str);
	strcat(display_str, "C ");			// add unit Celsius
	lcd_puts_xy(0,0, display_str);

	lcd_display();						// copy buffer to LCD
}

void welcome_lcd(void)
{									// symbol Tippel-Quad-Symbol
	for(uint8_t k=10; k<20; k++)	// enlarge symbol during start up
	{
	lcd_clrscr();
 	lcd_drawLine(CENTRE_X-30, CENTRE_Y, CENTRE_X+30, CENTRE_Y, WHITE);	// x axis
 	lcd_drawLine(CENTRE_X, CENTRE_Y-30, CENTRE_X, CENTRE_Y+30, WHITE);	// y axis
																		// 20 m quad
	lcd_drawLine(CENTRE_X, CENTRE_Y-27*k/20, CENTRE_X+27*k/20, CENTRE_Y, WHITE);	// top right 
	lcd_drawLine(CENTRE_X, CENTRE_Y-27*k/20, CENTRE_X-27*k/20, CENTRE_Y, WHITE);	// top left
	lcd_drawLine(CENTRE_X+27*k/20, CENTRE_Y, CENTRE_X, CENTRE_Y+27*k/20, WHITE);	// bottom right
	lcd_drawLine(CENTRE_X-27*k/20, CENTRE_Y, CENTRE_X, CENTRE_Y+27*k/20, WHITE);	// bottom left
																		// 15 m quad
	lcd_drawLine(CENTRE_X, CENTRE_Y-20*k/20, CENTRE_X+20*k/20, CENTRE_Y, WHITE);	// top right 
	lcd_drawLine(CENTRE_X, CENTRE_Y-20*k/20, CENTRE_X-20*k/20, CENTRE_Y, WHITE);	// top left
	lcd_drawLine(CENTRE_X+20*k/20, CENTRE_Y, CENTRE_X, CENTRE_Y+20*k/20, WHITE);	// bottom right
	lcd_drawLine(CENTRE_X-20*k/20, CENTRE_Y, CENTRE_X, CENTRE_Y+20*k/20, WHITE);	// bottom left
																		// 10 m quad
	lcd_drawLine(CENTRE_X, CENTRE_Y-15*k/20, CENTRE_X+15*k/20, CENTRE_Y, WHITE);	// top right 
	lcd_drawLine(CENTRE_X, CENTRE_Y-15*k/20, CENTRE_X-15*k/20, CENTRE_Y, WHITE);	// top left
	lcd_drawLine(CENTRE_X+15*k/20, CENTRE_Y, CENTRE_X, CENTRE_Y+15*k/20, WHITE);	// bottom right
	lcd_drawLine(CENTRE_X-15*k/20, CENTRE_Y, CENTRE_X, CENTRE_Y+15*k/20, WHITE);	// bottom left

	lcd_display();			
	_delay_ms(10);
	}

	_delay_ms(2000);
	lcd_clrscr();

	lcd_charMode(NORMALSIZE);		// select character size
	lcd_puts_xy(7,2,"Welcome");  	// welcome message to begin with
	lcd_puts_xy(2,4,"Clemens Verstappen");  
	lcd_puts_xy(7,6,"DL3ETW");  

	lcd_display();
	_delay_ms(1500);
	lcd_clrscr();
}

void draw_coordinate_system_lcd(void)		// draw coordinate system 
{
	for(uint8_t k=1; k<4; k++)				// makes 30 pixel / 10 V
	lcd_drawLine(OFFSET_X-4,OFFSET_Y - 15*k,OFFSET_X,OFFSET_Y - 15*k,WHITE);	// skalierung
	lcd_drawLine(OFFSET_X,7,OFFSET_X,62,WHITE);	 			// y axis
  	lcd_display();							// cpy buffer to LC display via I2C
}

uint8_t getTSicTemp(uint16_t *temp_value16)
{
	uint8_t 	i, j ,parity;
	uint16_t	strobe_time, strobe_count, temp_sr=0;

	cli();								// all interrups off 
	PORTC |= (1<<SENSOR_POWER);			// turn sensor on
	_delay_us(120);                  	// wait TSIC

    while(PINC & (1<<SENSOR_SIGNAL));           // warten auf high
    for (i=0;i<2;i++)                           // 2 Bytes Daten
    {
        strobe_time = 0;                        // fr Messung lschen
        while(PINC & (1<<SENSOR_SIGNAL));       // warten auf low
        										// Startbit, ab hier messen
        while(!( PINC & (1<<SENSOR_SIGNAL)))    // Low - Zeit messen
        {
            strobe_time++;                      // messen bitlnge
        }                                       // strobe_time hat ca. Wert 62 = 62s bei 40MHz
        parity = 0;
        for (j=0;j<8;j++)                       // 8 Datenbits
        {
            temp_sr <<= 1;                      // nach links verschieben,
                                                // Bit 0 wird automatisch auf 0 gesetzt
            strobe_count = strobe_time;         // Zhler laden
            while(PINC & (1<<SENSOR_SIGNAL));   // auf fallende Flanke warten

            while(strobe_count--) { Nop(); }    // hier die gemessene Bitzeit warten

            if (PINC & (1<<SENSOR_SIGNAL))      // PIN messen und Bit 0 setzen wenn high
            {
                temp_sr |= 0x01;
                parity++;                       // Paritt gleich mitzhlen
            }
            while(!( PINC & (1<<SENSOR_SIGNAL)));   // weiter wenn high
        } 										// ende bitcount
        										// Parity Bit
        strobe_count = strobe_time;             // Zhler laden
        while(PINC & (1<<SENSOR_SIGNAL));       // auf Low warten
        while(strobe_count--) { Nop(); }        // hier die gemessene Bitzeit warten
        if (PINC & (1<<SENSOR_SIGNAL)) parity++;// Parity Bit dazurechnen
        if (parity % 2 != 0) return 1;          // Parity Fehler (muss gerade Zahl sein)
        while(!( PINC & (1<<SENSOR_SIGNAL)));   // weiter wenn high
    } 											// ende Bytecount

	PORTC &= ~(1<<SENSOR_POWER);				// turn on sensor 
	*temp_value16 = temp_sr;					// copy result of 16 bit into temp_value16 address
	sei(); 										// interrups on
    return 0;									// measurement of temperature was succesfull, return with 1
}	

void display_temp_OLED(uint8_t error)
{
	display_str[0] 	= '\0';				// delete old contents
	temp_str[0]		= '\0';

	dtostrf(history[0], 2, 1, temp_str);	// convert float to ascii - TSic306
//	dtostrf(history[0], 2, 2, temp_str);	// convert float to ascii - TSic506 sensor two digits  

	lcd_puts_xy(0,1,"Temperatur");
	lcd_puts_xy(0,4,"          ");		// clear temp line	

	if (error == 0) 					// all fine display result
	{
		strcat(display_str, temp_str);		// add float into string
		strcat(display_str, " C");			// add unit Celsius
		lcd_puts_xy(4,4, display_str);		// now display temperature
	} 

	else if (error == 1) 
	{
		strcat(display_str, "SensorFault");	// add unit Celsius
		lcd_puts_xy(0,4, display_str);		// now display SensorFault
	} 

	lcd_display();						// copy to display
}

ISR(WDT_vect)							// Interrupt routine watchdog tripps 128 kHz clocksignal
{
	watchdog_flag = true;
	watchdog_counter++;					// each count equals 8.3 seconds
}			

SIGNAL(TIMER1_COMPA_vect) 				// MAIN INTERVAL, start for main loop 500 ms
{										 
	timer_flag = true;
	auto_sleep_counter++;
	if (auto_sleep_counter >= AUTO_OFF)	// swap into sleep mode and turn off display
	{
	    power_down_mode = true;			// switch off LCD and Controler in to Power down mode
		auto_sleep_counter = 60;		// avoid overflow
		button_flag = false;			// in case if it was set
	}
} 

ISR(PCINT0_vect)  						// encoder push button
{
	if	(!(PINB & (1<<PINB1)))			// check if low now (not high), I know ...
	{
		charMode++;
		if (charMode == 2)				// only MEASURE and GRAPH
			charMode = 0;
		button_flag = true;
	}
	auto_sleep_counter = 0;				// reset here, avoid auto switch off
}

ISR(INT0_vect)    						// rotary encoder A
{
	if (((PIND) & (1<<PIND3)) != A_set)	// check level of other encoder input
    A_set = !A_set;						// has it changed,  - store result

 	if (A_set && !B_set)				// level of A and B are different at slope of A
	{
		marker++;						// action: update marker. Pixel on x-axis (1 to 100 points )
		if (marker >= 100) 
			marker = 100;	

		encoder_right_flag = true;		// flag for main program
	}
	auto_sleep_counter = 0;				// reset here
}

ISR(INT1_vect)    						// rotary encoder B
{
	if (((PIND) & (1<<PIND2)) != B_set)	// check level of other encoder input
    B_set = !B_set;						// has it changed,  - store result

	if (B_set && !A_set)				// level of A and B are different at slope of B
	{
		marker--;						// action: update marker. Pixel on x-axis (1 to 100 points )
		if (marker <= 1) 
			marker = 1;

		encoder_left_flag = true;		// flag for main program
	}
	auto_sleep_counter = 0;
}

