/**************************************************************************************************
 *
 * Project:	ATMega328_SH1106 
 * File:	my_defines_mega328
 * Purpose:	configuration of controller pins and preprocessor defines
 * Version:	1.0
 * Date:	16.03.2021
 * Author:	Clemens Verstappen
 *
 **************************************************************************************************/
#define F_CPU 8000000UL 

#ifndef F_CPU
#define F_CPU 8000000UL 
# warning " CPU set to 8 MHz *Tewe "
#endif

#ifndef	__AVR_ATmega328P__
#define __AVR_ATmega328P__
# warning " __Controller set to ATmega328P *Tewe "
#endif
  
#define		TIMER_10MS			80			// time value for 10ms 
#define		TIMER_20MS			160			// time value for 20ms 
#define		TIMER_50MS			390			// time value for 50ms 
#define		TIMER_100MS			781			// time value for 100ms interrups of realtime_update 
#define		TIMER_250MS			1940		// time value for 500 ms 
#define		TIMER_500MS			3880		// time value for 500 ms 
#define		TIMER_1S			7760		// time value for  1 s   

#define		AUTO_OFF			120			// after 30 seconds auto switch off, 	120 after 60

#define		UPDATE				108			// 108 for about 15 min, of interrups of 8 seconds, 8 for 1 min, 2 for 16 s

#define 	Nop()  				asm volatile ("nop");
#define		MEASURE	0
#define		GRAPH	1

// LCD offset zum Ursprung vom Koordinatensystem (von oben/links gerechnet LCD(0,0)
#define		CENTRE_X	64		// fr Welcome, Symbol, from left of screen
#define		CENTRE_Y	32		// from top of screen

#define		OFFSET_X	20		// Ursprung des Koordinatensystems, from left of screen
#define		OFFSET_Y	60		// from top of screen

//-----------------------------------------------------------------------------------------------------
// pin assignement
//-----------------------------------------------------------------------------------------------------

// PORT B
#define 	LEBENSLICHT	PB0 	// (PCINT0/CKL0/ICP1)			
#define		ENC_SW		PB1 	// (OC1A/PCINT1)							
#define		LCD_POWER	PB2		// (SS/OC1B/PCINT3)						
#define		UNUSED_PB3	PB3		// (MOSI/OC2A/PCINT3))						
#define		UNUSED_PB4	PB4		// (MISO/PCINT4))							
#define		UNUSED_PB5	PB5 	// (SCK/PCINT5)							
#define		UNUSED_PB6	PB6		// (PCINT6/XTAL1/TOSC1)			
#define		UNUSED_PB7	PB7		// (PCINT7/XTAL2/TOSC2)	
		
// PORT C
#define		UNUSED_PC0	PC0 	// (ADC0/PCINT8)							
#define		UNUSED_PC1	PC1		// (ADC1/PCINT9)							
#define		SENSOR_POWER PC2	// (ADC2/PCINT10)								
#define		SENSOR_SIGNAL PC3	// (ADC3/PCINT11)								
#define		I2C_SDA		PC4		// (ADC4/SDA/PCINT12)							
#define		I2C_SCL		PC5		// (ADC5/SCL/PCINT13)							
#define		RESET		PC6		// (PCINT/RESET)			

// PORT D  			          										
#define		UNUSED_PD0	PD0		// (PCINT16/RXD)									
#define		TX			PD1		// (PCINT17/TXD)						
#define		ENC_B		PD2		// (PCINT18/INT0)							
#define		ENC_A		PD3		// (PCINT19/OC2B/INT1)				
#define		UNUSED_PD4	PD4		// (PCINT20/XCK/T0)					
#define		TEST_PIN	PD5		// (PCINT21/OC0B/T1)					
#define		UNUSED_PD6	PD6		// (PCINT22/OC0A/AIN0)						
#define		UNUSED_PD7	PD7		// (PCINT23/AIN1)							


// Pin assignment for ATtiny328P in 28 DIP Shape
// Belegung der Ports						PIN	Function			Signal name EAGLE Schaltplan Controler328_Mini
// Port B Bit 0 PB0 (PCINT0/CKL0/ICP1)		14	LEBENSLICHT			LEBENSLICHT		
//        Bit 1 PB1 (OC1A/PCINT1)			15	ENC_SW				ENC_SW			
//        Bit 2 PB2	(SS/OC1B/PCINT3)		16	LCD_POWER			LCD_POWER		
//        Bit 3 PB3	(MOSI/OC2A/PCINT3))		17	-/MOSI				
//        Bit 4 PB4	(MISO/PCINT4))			18	-/MISO				
//        Bit 5 PB5 (SCK/PCINT5)			19	-/SCK 				
//        Bit 6 PB6	(PCINT6/XTAL1/TOSC1)	9	-/8MHz X-TAL		
//		  Bit 7 PB7	(PCINT7/XTAL2/TOSC2)	10	-/8MHz X-TAL		

// Port C Bit 0 PC0 (ADC0/PCINT8)			23	-								
//        Bit 1 PC1	(ADC1/PCINT9)			24	-					
//        Bit 2 PC2	(ADC2/PCINT10)			25	SENSOR_POWER		SENSOR_POWER						
//        Bit 3 PC3	(ADC3/PCINT11)			26	SENSOR_SIGNAL		SENSOR_SIGNAL					
//        Bit 4 PC4	(ADC4/SDA/PCINT12)		27	I2C_SDA				SDA				
//        Bit 5 PC5	(ADC5/SCL/PCINT13)		28	I2C_SCL				SCK				
//        Bit 6 PC6	(PCINT/RESET)			1	RESET				RESET
  			          										
// Port D Bit 0 PD0	(PCINT16/RXD)			2	-									
//        Bit 1 PD1	(PCINT17/TXD)			3	TX					TX					
//        Bit 2 PD2	(PCINT18/INT0)			4	ENC_B				ENC_B					
//        Bit 3 PD3	(PCINT19/OC2B/INT1)		5	ENC_A				ENC_A			
//        Bit 4 PD4	(PCINT20/XCK/T0)		6	-				
//        Bit 5 PD5	(PCINT21/OC0B/T1)		11	TEST_PIN			TEST_PIN			
//        Bit 6 PD6	(PCINT22/OC0A/AIN0)		12	-				
//        Bit 7 PD7	(PCINT23/AIN1)			13	-				


