/*
 * i2c.c - I2C library for avr-gcc for devices with TWI
 *
 * Copyright (C) 2014 Jason Milldrum <milldrum@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "my_i2c.h"
// #include "project_defines.h"
// #include "global_defines.h"

void i2c_init(void)
{
	power_twi_enable();
//  PORT_PIN_SET(I2C_SDA_PORT, I2C_SDA);
//  PORT_PIN_SET(I2C_SCL_PORT, I2C_SCL);
//  PORT_PIN_OUTPUT(I2C_SDA_DDR, I2C_SDA);
//  PORT_PIN_OUTPUT(I2C_SCL_DDR, I2C_SCL);

	//set SCL rate
	TWSR = PSC_I2C;
	TWBR = SET_TWBR;

	//enable I2C
	TWCR = _BV(TWEN);
}

/**********************************************
 Public Function: i2c_start
 
 Purpose: Start TWI/I2C interface
 
 Input Parameter:
 - uint8_t i2c_addr: Adress of reciever
 
 Return Value: none
 **********************************************/
void i2c_start(uint8_t i2c_addr)
{
	TWCR = _BV(TWINT) | _BV(TWSTA) | _BV(TWEN);
	while (!(TWCR & _BV(TWINT)));
	TWDR = i2c_addr;
	TWCR = _BV(TWINT) | _BV(TWEN);
	while (!(TWCR & _BV(TWINT)));
}


void i2c_stop(void)
{
	TWCR = _BV(TWINT) | _BV(TWSTO) | _BV(TWEN);
}


void i2c_write(uint8_t data)
{
	TWDR = data;
	TWCR = _BV(TWINT) | _BV(TWEN);
	while (!(TWCR & _BV(TWINT)));
}


#ifdef I2C_READ_ACK_DEF
uint8_t i2c_read_ack(void)
{
	TWCR = _BV(TWINT) | _BV(TWEN) | _BV(TWEA);
	while (!(TWCR & _BV(TWINT)));
	return TWDR;
}
#endif

#ifdef I2C_READ_NACK_DEF
uint8_t i2c_read_nack(void)
{
	TWCR = _BV(TWINT) | _BV(TWEN);
	while (!(TWCR & _BV(TWINT)));
	return TWDR;
}
#endif

#ifdef I2C_STATUS_DEF
uint8_t i2c_status(void)
{
	return TW_STATUS;
}
#endif


