/**************************************************************************************************
 *
 * Projekt:	Antennen Analysator - AAN1
 * Datei:	my_uart.c
 * Zweck:	Treiber fr Serielle Schnittstelle UART
 * Version:	V1.0
 * Datum:	06.09.2019
 * Autor:	Christian Lilienthal, DG3KCL
 *
 * Dieser Code ist unter Vorlage der folgenden Beschreibung erstellt wworden:
 * //https://www.mikrocontroller.net/articles/AVR-GCC-Tutorial/Der_UART
 *
 *
 * Testumgebung
 * Leiterplatte:	AAN1_V01R01
 * Prozessor:		ATMega328P
 * Display:			OLED 128x64 SH1106
 *
 * 
 * Copyright (C):	2019 Christian Lilienthal, dg3kcl@mail.de
 *
 * This file is part of AAN1 software.
 *
 * AAN1 software is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or any later version.
 *
 * AAN1 software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Diese Datei ist Teil der AAN1 Software.
 *
 * AAN1 Software ist Freie Software: Sie knnen es unter den Bedingungen
 * der GNU General Public License, wie von der Free Software Foundation,
 * Version 3 der Lizenz oder jeder spteren
 * verffentlichten Version, weiterverbreiten und/oder modifizieren.
 *
 * AAN1 Software wird in der Hoffnung, dass es ntzlich sein wird, aber
 * OHNE JEDE GEWHRLEISTUNG, bereitgestellt; sogar ohne die implizite
 * Gewhrleistung der MARKTFHIGKEIT oder EIGNUNG FR EINEN BESTIMMTEN ZWECK.
 * Siehe die GNU General Public License fr weitere Details.
 *
 * Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 * Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
 *
 **************************************************************************************************/

#include "my_uart.h"
#include <avr/io.h>

#ifndef F_CPU
#define F_CPU 8000000 /* wird bentigt */
#endif

#ifndef BAUD
#define BAUD 9600UL
#endif


#define UBRR_VAL ((F_CPU+BAUD*8)/(BAUD*16)-1)	// Wert fr UBRR Register
#define BAUD_REAL (F_CPU/(16*(UBRR_VAL+1)))     // Reale Baudrate
#define BAUD_ERROR ((BAUD_REAL*1000)/BAUD)		// Fehler in Promille, 1000 = kein Fehler.
#if ((BAUD_ERROR<990) || (BAUD_ERROR>1010))		// zu hohe Fehler abfangen
  #error Systematischer Fehler der Baudrate grsser 1% und damit zu hoch! 
#endif


void uartInitTx(void)   
{
	UBRR0H = UBRR_VAL >> 8;
	UBRR0L = UBRR_VAL & 0xFF;

	UCSR0B |= (1<<TXEN0);				// UART TX einschalten
	UCSR0C = (1<<UCSZ01)|(1<<UCSZ00);	// Asynchron, 8bit, no parity, 1 stop
}

void uartInitTxRx(void)   
{
	UBRR0H = UBRR_VAL >> 8;
	UBRR0L = UBRR_VAL & 0xFF;

	UCSR0B |= (1<<RXEN0) |(1<<TXEN0);	// UART TX einschalten
	UCSR0C  = (1<<UCSZ01)|(1<<UCSZ00);	// Asynchron, 8bit, no parity, 1 stop
}


void uartPutc(unsigned char c)
{
    while (!(UCSR0A & (1<<UDRE0)))		// warten bis Senden moeglich
    {
    }                             

    UDR0 = c;	// sende Zeichen
}



void uartPuts(char *s)
{
    while (*s)	// beendet durch NULL
    {
        uartPutc(*s);
        s++;
    }
}




